package Locale::CLDR::Gsw::Any v0.25.0;
# This file auto generated
#	on Mon 21 Apr 11:04:58 pm GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Gsw');

no Moose;
__PACKAGE__->meta->make_immutable;
